Index: src/mips/simulator-mips.h |
diff --git a/src/mips/simulator-mips.h b/src/mips/simulator-mips.h |
index 67f595302b720c0b61ab73088a2ed029a33689e7..ed6344342dca04d9e51a4cecca36e611672dfdf2 100644 |
--- a/src/mips/simulator-mips.h |
+++ b/src/mips/simulator-mips.h |
@@ -391,14 +391,14 @@ class Simulator { |
static const uint32_t kStopDisabledBit = 1 << 31; |
// A stop is enabled, meaning the simulator will stop when meeting the |
// instruction, if bit 31 of watched_stops[code].count is unset. |
// The value watched_stops[code].count & ~(1 << 31) indicates how many times |
// the breakpoint was hit or gone through. |
struct StopCountAndDesc { |
uint32_t count; |
char* desc; |
}; |
- StopCountAndDesc watched_stops[kMaxStopCode + 1]; |
+ StopCountAndDesc watched_stops_[kMaxStopCode + 1]; |
}; |
@@ -391,14 +391,14 @@ class Simulator { |
static const uint32_t kStopDisabledBit = 1 << 31; |
// A stop is enabled, meaning the simulator will stop when meeting the |
- // instruction, if bit 31 of watched_stops[code].count is unset. |
- // The value watched_stops[code].count & ~(1 << 31) indicates how many times |
+ // instruction, if bit 31 of watched_stops_[code].count is unset. |
+ // The value watched_stops_[code].count & ~(1 << 31) indicates how many times |
// the breakpoint was hit or gone through. |
struct StopCountAndDesc { |